package com.example;

import java.io.BufferedReader;
import java.io.IOException;
import java.io.InputStreamReader;
import java.io.PrintWriter;
import java.net.Socket;

public class ClientHandler implements Runnable {

    private final Socket socket;

    public ClientHandler(Socket socket) {
        this.socket = socket;
    }

    @Override
    public void run() {
        BufferedReader in = null;
        PrintWriter out = null;

        try {
            in = new BufferedReader(new InputStreamReader(socket.getInputStream()));
            out = new PrintWriter(socket.getOutputStream(), true);

            System.out.println("Client connected: " + socket.getInetAddress());

            String rawMessage;
            while ((rawMessage = in.readLine()) != null) {
                // System.out.println("📨 Received: " + rawMessage);
                System.out.println("📨 Received Request" );

                String response = EventHandler.handleEvent(rawMessage); // all fingerprint data goes through here
                // System.out.println("📤 Responding: " + response);
                out.println(response); // this is the part that is emits to the client
            }

            System.out.println("Client disconnected: " + socket.getInetAddress());

        } catch (IOException e) {
            System.err.println("Client handler error: " + e.getMessage());
        } finally {
            try {
                if (in != null) {
                    in.close();
                }
                if (out != null) {
                    out.close();
                }
                socket.close();
            } catch (IOException e) {
                System.err.println("Error closing client socket: " + e.getMessage());
            }
        }
    }

}
